Learn R Programming

otelsdk (version 0.2.2)

otelsdk-package: otelsdk: 'R' 'SDK' and Exporters for 'OpenTelemetry'

Description

'OpenTelemetry' is a collection of tools, 'APIs', and 'SDKs' used to instrument, generate, collect, and export telemetry data (metrics, logs, and traces) for analysis in order to understand your software's performance and behavior. This package contains the 'OpenTelemetry' 'SDK', and exporters. Use this package to export traces, metrics, logs from instrumented 'R' code. Use the 'otel' package to instrument your 'R' code for 'OpenTelemetry'.

Arguments

Value

Not applicable.

Author

Maintainer: Gábor Csárdi csardi.gabor@gmail.com

Other contributors:

  • Posit Software, PBC (ROR) [copyright holder, funder]

  • opentelemetry-cpp authors [contributor]

See Also

Examples

Run this code
# Run your R script with OpenTelemetry tracing:
# OTEL_TRACER_EXPORTER=otlp R -f myapp.R

Run the code above in your browser using DataLab