powered by
Writes spans to the standard output or error, or to a file. Useful for debugging.
tracer_provider_stdstream$new() returns an otel::otel_tracer_provider
tracer_provider_stdstream$new()
object.
tracer_provider_stdstream$options() returns a named list, the current values of the options.
tracer_provider_stdstream$options()
Externally:
OTEL_TRACES_EXPORTER=console OTEL_TRACES_EXPORTER=stderr
From R:
tracer_provider_stdstream$new(opts = NULL) tracer_provider_stdstream$options()
opts: Named list of options. See below.
opts
output: where to write the output. Can be
output
"stdout": write output to the standard output,
"stdout"
"stderr": write output to the standard error,
"stderr"
another string: write output to a file. (To write output to a file named "stdout" or "stderr", use a ./ prefix.)
./
Value is set from
the opts argument, or
the OTEL_R_EXPORTER_STDSTREAM_TRACES_OUTPUT environment variable, or
OTEL_R_EXPORTER_STDSTREAM_TRACES_OUTPUT
the OTEL_R_EXPORTER_STDSTREAM_OUTPUT environment variable, or
OTEL_R_EXPORTER_STDSTREAM_OUTPUT
the default is "stdout".
Run the code above in your browser using DataLab