powered by
otel and otelsdk accept file size options in the following format:
As a positive numeric scalar, interpreted as number of bytes.
A string scalar with a positive number and a unit suffix. Possible units: B, KB, KiB, MB, MiB, GB, GiB, TB, TiB, PB, PiB. Units are case insensitive.
Not applicable.
# Maximum output file size is 128 MiB: # OTEL_EXPORTER_OTLP_FILE_FILE_SIZE=128MiB
Run the code above in your browser using DataLab