powered by
Writes logs to the standard output or error, or to a file. Useful for debugging.
logger_provider_stdstream$new() returns an otel::otel_logger_provider
logger_provider_stdstream$new()
object.
logger_provider_stdstream$options() returns a named list, the current values of the options.
logger_provider_stdstream$options()
Externally:
OTEL_LOGS_EXPORTER=console OTEL_LOGS_EXPORTER=stderr
From R:
logger_provider_stdstream$new(opts = NULL) logger_provider_stdstream$options()
opts: Named list of options. See below.
opts
output: where to write the output. Can be
output
"stdout": write output to the standard output,
"stdout"
"stderr": write output to the standard error,
"stderr"
another string: write output to a file. (To write output to a file named "stdout" or "stderr", use a ./ prefix.)
./
Value is set from
the opts argument, or
the OTEL_R_EXPORTER_STDSTREAM_LOGS_OUTPUT environment variable, or
OTEL_R_EXPORTER_STDSTREAM_LOGS_OUTPUT
the OTEL_R_EXPORTER_STDSTREAM_OUTPUT environment variable, or
OTEL_R_EXPORTER_STDSTREAM_OUTPUT
the default is "stdout".
Run the code above in your browser using DataLab